@@ -17,7 +17,9 @@ def patch_get_content(name):
 @patch_get_content('fmelli.html')
 def test_get_page_info():
     d = Instrument(1).get_page_info()
-    assert d.items() >= {
+    trade_history = d.pop('trade_history')
+    related_companies = d.pop('related_companies')
+    assert d == {
         'tmax': 19820.0
         , 'tmin': 21900.0
         , 'bvol': 5479452
@@ -33,8 +35,8 @@ def test_get_page_info():
         , 'week_max': 22000.0
         , 'week_min': 20010.0
         , 'year_max': 39810.0
-        , 'year_min': 5181.0
-        , 'related_companies': [
+        , 'year_min': 5181.0}
+    assert related_companies == [
             [46348559193224090, 'فولاد', 'فولاد مبارکه اصفهان']
             , [35425587644337450, 'فملی', 'ملی\u200c صنایع\u200c مس\u200c ایران\u200c']
             , [9211775239375291, 'ذوب', 'سهامی ذوب آهن  اصفهان']
@@ -83,8 +85,7 @@ def test_get_page_info():
             , [48175603054578540, 'اسفراین', 'مجتمع صنعتی اسفراین']
             , [58903026391426893, 'سیرجان', 'فولاد سیرجان']
             , [68604686987554533, 'فماکح', 'ح . ماداکتو استیل کرد']]
-    }.items()
-    assert d['trade_history'].to_dict() == {
+    assert trade_history.to_dict() == {
         'pc': {20201021: 23990.0, 20201024: 22900.0, 20201026: 21800.0, 20201027: 20790.0, 20201028: 20580.0, 20201031: 21540.0, 20201101: 20910.0, 20201102: 20860.0, 20201104: 21900.0}
         , 'pmax': {20201021: 24790.0, 20201024: 23730.0, 20201026: 22700.0, 20201027: 22050.0, 20201028: 21420.0, 20201031: 21600.0, 20201101: 22000.0, 20201102: 21490.0, 20201104: 21900.0}
         , 'pmin': {20201021: 22660.0, 20201024: 22800.0, 20201026: 21760.0, 20201027: 20710.0, 20201028: 19760.0, 20201031: 20650.0, 20201101: 20480.0, 20201102: 20010.0, 20201104: 21510.0}
